@@ -8,6 +8,6 @@ CMSPLUGIN_SATCHMO_SETTINGS = getattr(settings, 'SATCHMO_SETTINGS', {
 	'PRODUCT_SLUG': 'products',
 	'CATEGORY_SLUG': 'category',
 })
-PRODUCT_URL_PATH = '%s%s' % (CMSPLUGIN_SATCHMO_SETTINGS['SHOP_BASE'], CMSPLUGIN_SATCHMO_SETTINGS['PRODUCT_SLUG'])
-CATEGORY_URL_PATH = '%s%s' % (CMSPLUGIN_SATCHMO_SETTINGS['SHOP_BASE'], CMSPLUGIN_SATCHMO_SETTINGS['CATEGORY_SLUG'])
+PRODUCT_URL_PATH = '%s%s/' % (CMSPLUGIN_SATCHMO_SETTINGS['SHOP_BASE'], CMSPLUGIN_SATCHMO_SETTINGS['PRODUCT_SLUG'])
+CATEGORY_URL_PATH = '%s%s/' % (CMSPLUGIN_SATCHMO_SETTINGS['SHOP_BASE'], CMSPLUGIN_SATCHMO_SETTINGS['CATEGORY_SLUG'])
 
